Properties Methods Events Config Options Direct Link

# Class Ext.ensible.cal.CalendarList

Package: | Ext.ensible.cal
Defined In: | CalendarList.js
Class: | CalendarList
Extends: | Object

This is a panel subclass that renders a list of available calendars

## Config Options

Config Options | Defined By
--- | ---
| store : Ext.data.Store A store containing records of type CalendarRecord. This is a required config and is used to populate the calendar lis... A store containing records of type CalendarRecord. This is a required config and is used to populate the calendar list. The CalendarList widget will also listen for events from the store and automatically refresh iteself in the event that the underlying calendar records in the store change. | CalendarList

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| CalendarList( `Object config` ) Parameters: `config` : Object The config object Returns: void | CalendarList
| refresh() : void Refreshes the calendar list so that it displays based on the most current state of the underlying calendar store. Usu... Refreshes the calendar list so that it displays based on the most current state of the underlying calendar store. Usually this method does not need to be called directly as the control is automatically bound to the store's events, but it is available in the event that a manual refresh is ever needed. Parameters: None. Returns: void | CalendarList
| setStore( `Ext.data.Store store` ) : void Sets the store used to display the available calendars. It should contain records of type CalendarRecord. Sets the store used to display the available calendars. It should contain records of type CalendarRecord. Parameters: `store` : Ext.data.Store Returns: void | CalendarList

## Public Events

This class has no public events.